@@ -86,8 +86,8 @@ LBLDATADISP = "Console Display"
 LBLUBXCONFIG = "UBX Configuration"
 LBLCTL = "Controls"
 LBLSET = "Settings"
-LBLCFGPRT = "CFG-PRT Port and Protocol Configuration"
-LBLCFGMSG = "CFG-MSG - UBX & NMEA Message Rate / Port Selection"
+LBLCFGPRT = "CFG-PRT Protocol Configuration"
+LBLCFGMSG = "CFG-MSG Message Rate Configuration"
 LBLPRESET = "Preset UBX Configuration Commands"
 LBLDATALOG = "Enable DataLog"
 LBLSTREAM = "Stream\nfrom file"
